<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:java="http://xml.apache.org/xslt/java"
		xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
		xmlns:gslib="http://www.greenstone.org/skinning"
		xmlns:gsf="http://www.greenstone.org/greenstone3/schema/ConfigFormat"		
		extension-element-prefixes="java util"
		exclude-result-prefixes="java util xsl gslib">

  
  <!-- use the 'main' layout -->
  <xsl:include href="layouts/main.xsl"/>
  
  <!-- set page title -->
  <xsl:template name="pageTitle">
    <gslib:siteName/>
  </xsl:template>


  <!-- This and the following template rule is copied verbatim from document.xsl -->
  
  <xsl:template name="javascriptForDocumentView">
    <script type="text/javascript" src="interfaces/{$interface_name}/js/utility_scripts.js"><xsl:text> </xsl:text></script>
    <script type="text/javascript" src="interfaces/{$interface_name}/js/document_scripts.js"><xsl:text> </xsl:text></script>
    <gsf:metadata name="Thumb" hidden="true"/>
    <script type="text/javascript">
      <xsl:text disable-output-escaping="yes">
   	function goToAnchor(sectionID,anchor)
	{
	    var docIdentifier = '</xsl:text><xsl:value-of select="//documentNode[@nodeType = 'root']/@nodeID"/><xsl:text disable-output-escaping="yes">';
	    focusAnchor(docIdentifier + "."+ sectionID,0,1,anchor);
	}
      </xsl:text>
    </script>
    <xsl:call-template name="customJavascriptForDocumentView"/>
  </xsl:template>

  <!-- Use this to add in extra javascript/files for an interface, site, collection -->
  <xsl:template name="customJavascriptForDocumentView">
  </xsl:template>

  <!-- the main layout is defined here -->
  <xsl:template name="mainTemplate">
    
    <html lang="{$lang}">
      
      <head>
        <!-- ***** in header.xsl ***** -->
        <xsl:call-template name="create-html-header" />
	<xsl:call-template name="javascriptForDocumentView"/>

	
	<!-- Import as bundled (All-in-one): -->
	<!-- <script src="dist/winbox.bundle.min.js"></script> -->
	
	<!-- Or import JS + CSS separately: -->
	<!--
	    <link rel="stylesheet" href="winbox-dist/css/winbox.min.css">
	    <script src="winbox-dist/js/winbox.min.js"></script>
	-->
	<gsf:style  src="ext/tabletop-dl/winbox-with-interactjs-dist/css/winbox.min.css" />
	<gsf:script src="ext/tabletop-dl/winbox-with-interactjs-dist/js/winbox.min.js"/>
	<gsf:script src="ext/tabletop-dl/interactjs-dist/interact.min.js"/>
	<gsf:script src="ext/tabletop-dl/winbox-interact.js"/>
	
   	<gsf:style  src="ext/tabletop-dl/tabletop.css" />
	<!--
	<gsf:style  src="ext/tabletop-dl/tabletop-theme-default.css" id="tabletop-theme-style-elem"/>
	-->
	<link href="ext/tabletop-dl/tabletop-theme-default.css" rel="stylesheet" type="text/css" id="tabletop-theme-style-elem"/>
	  
	<gsf:script src="ext/tabletop-dl/tabletop.js"/>

      </head>
      
            <body>
	      <xsl:call-template name="textDirectionAttribute" />
              <xsl:call-template name="actionClass" />
              <!-- Consider bringing this template call back, but wrapped up in an "if debug" ?? -->
              <!--<xsl:call-template name="displayErrorsIfAny"/>-->
	      

	      <div class="tabletop-box">
		<!-- currently not displayed/used -->
		<div id="gs-tabletop-header" class="tabletop-row tabletop-header" style="display: none;">
		  <div style="padding-top: 0.6em;">Greenstone3 Tabletop Digital Library</div>
		</div>
		
		<div class="tabletop-row tabletop-content" style="margin: 0.5em;">
		  
		  <div style="position: relative; width: 100%; height: 100%;">
		    <gsf:div id="gs-css-root-primary"/> <!-- used to so JS can access root CSS values -->
		    
		    <div id="gs-control-bar">
		      <div style="float: right; color: white; margin-top: 0.6em; margin-right: 0.6em;">
			Theme:
			<select id="gs-control-bar-theme-selection">
			    <option value="default">Default</option>
			    <option value="leafytrees">Leafy Trees</option>
			</select>
		      </div>
		      <div style="padding-top: 0.6em;">Greenstone Tabletop Digital Library</div>
		    </div>
		    
		    <div id="gs-control-bar-toggle" class="tabletop-button">&#9776;</div>

		    <div id="gs-home-open" class="tabletop-button">
		      <img src="interfaces/{$interface_name}/images/logo-icons/server32.png" width="32" height="32"/>
		    </div>
		    		    		    		    
		  </div>

		  <!--
		      <div id="my-own-window"
		      style="position: absolute; left: 30px; top: 430px; width: 400px; height: 300px; background-color: red;">
		      </div>
		  -->
	
	  
		</div>

		<!-- currently not displayed/used -->
		<div id="gs-tabletop-footer" class="tabletop-row tabletop-footer" style="display:none;">
		  <p>Tabletop powered by Grenstone3</p>
		</div>
	      </div>
    	      	      
            </body>
    </html>
  </xsl:template>
  
  
  <!--
      The following is done in home.xsl, do we need to do the same here ?
      <xsl:template match="/page/xsltparams">
        < !- - suppress xsltparam block in page - - >
      </xsl:template>
  -->
    
</xsl:stylesheet>


